package com.muyu.eventdriven.config.rabbit;

import com.muyu.eventdriven.constants.RabbitConstants;
import org.springframework.amqp.core.Binding;
import org.springframework.amqp.core.BindingBuilder;
import org.springframework.amqp.core.DirectExchange;
import org.springframework.amqp.core.Queue;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;

/**
 * @ClassName RabbitRoutingConfig
 * @Description rabbit配置类
 * @Author Yunfei.Du
 * @Date 2024/6/21 上午11:35
 */
@Configuration
public class RabbitRoutingConfig {
    /**
     * Queue 可以有4个参数
     * 1.name          队列名
     * 2.durable       持久化消息队列 ,rabbitmq重启的时候不需要创建新的队列 默认true
     * 3.auto-delete   表示消息队列没有在使用时将被自动删除 默认是false
     * 4.exclusive     表示该消息队列是否只在当前connection生效,默认是false
     */
    @Bean
    public Queue createRoutingQueueA() {
        return new Queue(RabbitConstants.QUEUE_STATUS_ABNORMAL, true);
    }

    @Bean
    public Queue createRoutingQueueB() {
        return new Queue(RabbitConstants.QUEUE_STATUS_NORMAL, true);
    }

    @Bean
    public DirectExchange routingExchange() {
        //配置广播路由器
        return new DirectExchange(RabbitConstants.EXCHANGE_STATUS);
    }

    @Bean
    public Binding bingQueueAToRoutingExchange() {
        return BindingBuilder.bind(createRoutingQueueA()).to(routingExchange()).with(RabbitConstants.STATUS_ABNORMAL);
    }

    @Bean
    public Binding bingQueueBToRoutingExchange() {
        return BindingBuilder.bind(createRoutingQueueB()).to(routingExchange()).with(RabbitConstants.STATUS_NORMAL);
    }
}
