package com.muyu.eventdriven.consumer.redis;

import com.alibaba.fastjson.JSON;
import com.muyu.eventdriven.constants.RabbitConstants;
import com.muyu.eventdriven.constants.RedisConstants;
import com.muyu.eventdriven.domain.RabbitFalut;
import com.muyu.eventdriven.domain.VehicleFaultStatus;
import lombok.extern.log4j.Log4j2;
import org.springframework.amqp.rabbit.core.RabbitTemplate;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.redis.connection.Message;
import org.springframework.data.redis.listener.KeyExpirationEventMessageListener;
import org.springframework.data.redis.listener.RedisMessageListenerContainer;
import org.springframework.stereotype.Component;

import java.util.Date;
import java.util.UUID;

/**
 * @ClassName RedisKeyExpirationListener
 * @Description redsi键过期监听类
 * @Author Yunfei.Du
 * @Date 2024/6/21 上午11:27
 */
@Log4j2
@Component
public class RedisKeyExpirationListener extends KeyExpirationEventMessageListener {
    @Autowired
    private RabbitTemplate rabbitTemplate;

    public RedisKeyExpirationListener(RedisMessageListenerContainer listenerContainer) {
        super(listenerContainer);
    }

    //拿到过期key的信息并做处理
    @Override
    public void onMessage(Message messages, byte[] pattern) {
        String key = messages.toString();
        if (key.contains(RedisConstants.VEHICLE_FAULT_KEY)){
            String[] split = key.split(":");
            RabbitFalut rabbitFalut = new RabbitFalut();
            rabbitFalut.setEndTime(new Date());
            rabbitFalut.setVin(split[1]);
            rabbitFalut.setFaultCode(split[2]);
            rabbitTemplate.convertAndSend(RabbitConstants.EXCHANGE_STATUS,RabbitConstants.QUEUE_STATUS_ABNORMAL, JSON.toJSONString(rabbitFalut),message ->{
                message.getMessageProperties().setMessageId( UUID.randomUUID().toString());
                //设置消息延迟时间为5秒
                message.getMessageProperties().setDelay(5000);
                log.info ( "消息发送成功" );
                return message;
            });
        }
    }
}
