package com.muyu.eventdriven.domain;

import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.NoArgsConstructor;
import lombok.experimental.SuperBuilder;

import java.math.BigDecimal;

/**
 * @ClassName VehicleData
 * @Description 描述
 * @Author Yunfei.Du
 * @Date 2024/6/5 下午6:52
 */
@Data
@SuperBuilder
@AllArgsConstructor
@NoArgsConstructor
public class VehicleData {

    /**
     * VIN
     */
    private String vin;

    /**
     * 行驶路线
     */
    private String drivingRoute;


    /**
     * 经度
     */
    private String longitude;

    /**
     * 维度
     */
    private String latitude;
    /**
     * 速度
     */
    private String speed;

    /**
     * 里程
     */
    private BigDecimal mileage;

    /**
     * 总电压
     */
    private String voltage;

    /**
     * 总电流
     */
    private String current;

    /**
     * 绝缘电阻
     */
    private String resistance;

    /**
     * 档位
     */
    private String gear = "P";

    /**
     * 加速踏板行程值
     */
    private String accelerationPedal;

    /**
     * 制动踏板行程值
     */
    private String brakePedal;

    /**
     * 燃料消耗率
     */
    private String fuelConsumptionRate;

    /**
     * 电机控制器温度
     */
    private String motorControllerTemperature;

    /**
     * 电机转速
     */
    private String motorSpeed;

    /**
     * 电机转矩
     */
    private String motorTorque;

    /**
     * 电机温度
     */
    private String motorTemperature;

    /**
     * 电机电压
     */
    private String motorVoltage;

    /**
     * 电机电流
     */
    private String motorCurrent;

    /**
     * 动力电池剩余电量SOC
     */
    private BigDecimal remainingBattery;

    /**
     * 电池总容量
     */
    private BigDecimal batteryLevel;

    /**
     * 当前状态允许的最大反馈功率
     */
    private String maximumFeedbackPower;

    /**
     * 当前状态允许最大放电功率
     */
    private String maximumDischargePower;

    /**
     * BMS自检计数器
     */
    private String selfCheckCounter;

    /**
     * 动力电池充放电电流
     */
    private String totalBatteryCurrent;

    /**
     * 动力电池负载端总电压V3
     */
    private String totalBatteryVoltage;

    /**
     * 单次最大电压
     */
    private String singleBatteryMaxVoltage;

    /**
     * 单体电池最低电压
     */
    private String singleBatteryMinVoltage;

    /**
     * 单体电池最高温度
     */
    private String singleBatteryMaxTemperature;

    /**
     * 单体电池最低温度
     */
    private String singleBatteryMinTemperature;

    /**
     * 动力电池可用容量
     */
    private String availableBatteryCapacity;

    /**
     * 车辆状态
     */
    private int vehicleStatus = 1;

    /**
     * 充电状态
     */
    private int chargingStatus = 1;

    /**
     * 运行状态
     */
    private int operatingStatus = 1;

    /**
     * SOC
     */
    private int socStatus = 1;

    /**
     * 可充电储能装置工作状态
     */
    private int chargingEnergyStorageStatus = 1;

    /**
     * 驱动电机状态
     */
    private int driveMotorStatus = 1;

    /**
     * 定位是否有效
     */
    private int positionStatus = 1;

    /**
     * EAS(汽车防盗系统)状态
     */
    private int easStatus = 1;

    /**
     * PTC(电动加热器)状态
     */
    private int ptcStatus = 1;

    /**
     * EPS(电动助力系统)状态
     */
    private int epsStatus = 1;

    /**
     * ABS(防抱死)状态
     */
    private int absStatus = 1;

    /**
     * MCU(电机/逆变器)状态
     */
    private int mcuStatus = 1;

    /**
     * 动力电池加热状态
     */
    private int heatingStatus = 1;

    /**
     * 动力电池当前状态
     */
    private int batteryStatus = 1;

    /**
     * 动力电池保温状态
     */
    private int batteryInsulationStatus = 1;

    /**
     * DCDC(电力交换系统)状态
     */
    private int dcdcStatus = 1;

    /**
     * CHG(充电机)状态
     */
    private int chgStatus = 1;
}
