package com.muyu.eventdriven.tactics.basics;

import com.muyu.eventdriven.domain.VehicleData;
import com.muyu.eventdriven.server.IotDbServer;
import com.muyu.eventdriven.tactics.EventTactics;
import lombok.extern.log4j.Log4j2;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Primary;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * @ClassName StorageEvent
 * @Description 存储事件
 * @Author Yunfei.Du
 * @Date 2024/6/20 上午10:38
 */
@Service("StorageEvent")
@Log4j2
@Primary
public class StorageEvent implements EventTactics {
    @Autowired
    private IotDbServer iotDbServer;

    /**
     * 单条数据的处理
     * @param vehicleData
     */
    @Override
    public void eventManage(VehicleData vehicleData) {
        iotDbServer.insertData(vehicleData);
        log.info("车辆{}执行存储事件",vehicleData.getVin());
    }

    /**
     * 多条数据的处理
     * @param vin
     * @param vehicleDataList
     */
    @Override
    public void eventManage(String vin, List<VehicleData> vehicleDataList) {
        log.info("车辆{}执行存储事件",vin);
        vehicleDataList.forEach(vehicleData -> {
            iotDbServer.insertData(vehicleData);
        });
    }
}
