package com.muyu.eventdriven.tactics.system;

import com.alibaba.fastjson.JSON;
import com.muyu.eventdriven.domain.VehicleData;
import com.muyu.eventdriven.tactics.EventTactics;
import lombok.extern.log4j.Log4j2;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * @ClassName RealTimeDataEvent
 * @Description 实时数据
 * @Author Yunfei.Du
 * @Date 2024/6/20 上午10:47
 */
@Service("RealTimeDataEvent")
@Log4j2
public class RealTimeDataEvent implements EventTactics {
    @Autowired
    private RedisTemplate<String,String> redisTemplate;

    @Override
    public void eventManage(VehicleData vehicleData) {
        if (redisTemplate.hasKey(vehicleData.getVin())){
            log.info("{}监听到的消息内容: {}", vehicleData.getVin(),vehicleData);
            redisTemplate.opsForList().rightPush(vehicleData.getVin(), JSON.toJSONString(vehicleData));
        }
        log.info("车辆{}执行实时数据事件",vehicleData.getVin());
    }

    @Override
    public void eventManage(String vin, List<VehicleData> vehicleDataList) {
        log.info("车辆{}执行实时数据事件",vin);
        if (redisTemplate.hasKey(vin)){
            log.info("{}监听到的消息内容: {}", vin,vehicleDataList);
            vehicleDataList.forEach(vehicleData -> {
                redisTemplate.opsForList().rightPush(vin, JSON.toJSONString(vehicleData));
            });
        }
    }
}
